==> quarkus-core-1.11.0.Final-sources.jar: io/quarkus/runtime/logging/FileConfig$RotationConfig$$accessor.java <==
package io.quarkus.runtime.logging;
public final class FileConfig$RotationConfig$$accessor {
    private FileConfig$RotationConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_maxFileSize(Object __instance) {
        return ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).maxFileSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_maxFileSize(Object __instance, Object maxFileSize) {
        ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).maxFileSize = (java.util.Optional<io.quarkus.runtime.configuration.MemorySize>)maxFileSize;
    }
    @SuppressWarnings("unchecked")
    public static int get_maxBackupIndex(Object __instance) {
        return ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).maxBackupIndex;
    }
    @SuppressWarnings("unchecked")
    public static void set_maxBackupIndex(Object __instance, int maxBackupIndex) {
        ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).maxBackupIndex = maxBackupIndex;
    }
    @SuppressWarnings("unchecked")
    public static Object get_fileSuffix(Object __instance) {
        return ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).fileSuffix;
    }
    @SuppressWarnings("unchecked")
    public static void set_fileSuffix(Object __instance, Object fileSuffix) {
        ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).fileSuffix = (java.util.Optional<String>)fileSuffix;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_rotateOnBoot(Object __instance) {
        return ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).rotateOnBoot;
    }
    @SuppressWarnings("unchecked")
    public static void set_rotateOnBoot(Object __instance, boolean rotateOnBoot) {
        ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).rotateOnBoot = rotateOnBoot;
    }
}

==> quarkus-core-3.1.1.Final-sources.jar: io/quarkus/runtime/logging/FileConfig$RotationConfig$$accessor.java <==
package io.quarkus.runtime.logging;
public final class FileConfig$RotationConfig$$accessor {
    private FileConfig$RotationConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_maxFileSize(Object __instance) {
        return ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).maxFileSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_maxFileSize(Object __instance, Object maxFileSize) {
        ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).maxFileSize = (io.quarkus.runtime.configuration.MemorySize)maxFileSize;
    }
    @SuppressWarnings("unchecked")
    public static int get_maxBackupIndex(Object __instance) {
        return ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).maxBackupIndex;
    }
    @SuppressWarnings("unchecked")
    public static void set_maxBackupIndex(Object __instance, int maxBackupIndex) {
        ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).maxBackupIndex = maxBackupIndex;
    }
    @SuppressWarnings("unchecked")
    public static Object get_fileSuffix(Object __instance) {
        return ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).fileSuffix;
    }
    @SuppressWarnings("unchecked")
    public static void set_fileSuffix(Object __instance, Object fileSuffix) {
        ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).fileSuffix = (java.util.Optional<String>)fileSuffix;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_rotateOnBoot(Object __instance) {
        return ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).rotateOnBoot;
    }
    @SuppressWarnings("unchecked")
    public static void set_rotateOnBoot(Object __instance, boolean rotateOnBoot) {
        ((io.quarkus.runtime.logging.FileConfig.RotationConfig)__instance).rotateOnBoot = rotateOnBoot;
    }
}
